import { HexEncodedAmount } from '../../utils';
declare enum TokenSchemeType {
    Simple = 0
}
declare abstract class TokenScheme {
    private type;
    constructor(type: TokenSchemeType);
    /**
     * The type of token scheme.
     */
    getType(): TokenSchemeType;
}
/**
 * Simple token scheme.
 */
declare class SimpleTokenScheme extends TokenScheme {
    private mintedTokens;
    private meltedTokens;
    private maximumSupply;
    constructor(mintedTokens: HexEncodedAmount, meltedTokens: HexEncodedAmount, maximumSupply: HexEncodedAmount);
    /**
     * Amount of tokens minted.
     */
    getMintedTokens(): HexEncodedAmount;
    /**
     * Amount of tokens melted.
     */
    getMeltedTokens(): HexEncodedAmount;
    /**
     * Maximum supply of tokens controlled.
     */
    getMaximumSupply(): HexEncodedAmount;
}
declare const TokenSchemeDiscriminator: {
    property: string;
    subTypes: {
        value: typeof SimpleTokenScheme;
        name: any;
    }[];
};
export { TokenSchemeDiscriminator, TokenScheme, TokenSchemeType, SimpleTokenScheme, };
